@@ -1756,6 +1756,7 @@ class HeatMixin(_HeadLossMixin, BaseComponentTypeMixin, CollocatedIntegratedOpti
             heat_in = results[f"{p}.HeatIn.Heat"]
             heat_out = results[f"{p}.HeatOut.Heat"]
             inds = np.abs(heat_out) > np.abs(heat_in)
+            nominal = self.variable_nominal(f"{p}.HeatIn.Heat")
 
             heat = heat_in.copy()
             heat[inds] = heat_out[inds]
@@ -1772,7 +1773,9 @@ class HeatMixin(_HeadLossMixin, BaseComponentTypeMixin, CollocatedIntegratedOpti
 
                 inds_disconnected = is_disconnected == 1
 
-                np.testing.assert_allclose(heat[inds_disconnected], 0.0, atol=1e-5, rtol=1e-5)
+                np.testing.assert_allclose(
+                    heat[inds_disconnected] / nominal, 0.0, atol=1e-5, rtol=0
+                )
 
                 np.testing.assert_array_equal(
                     np.sign(heat[~inds_disconnected]), 2 * flow_dir_var[~inds_disconnected] - 1
